@@ -1,5 +1,6 @@
 use crev_data::{proof, Digest, PublicId, Version};
 use crev_lib::*;
+use crev_wot::TrustSet;
 use std::path::PathBuf;
 
 use crate::{opts::*, prelude::*, shared::*, term};
@@ -9,6 +10,8 @@ use std::{
     ops::Add,
 };
 
+use self::scan::RequiredDetails;
+
 mod print_term;
 pub mod scan;
 
@@ -286,7 +289,9 @@ pub fn crate_mvps(crate_: CrateSelector, common: CrateVerifyCommon) -> Result<()
     args.common = common;
 
     let scanner = scan::Scanner::new(crate_, &args)?;
-    let events = scanner.run();
+    let trust_set = scanner.trust_set.clone();
+    let db = scanner.db.clone();
+    let events = scanner.run(&RequiredDetails::none());
 
     let mut mvps: HashMap<PublicId, u64> = HashMap::new();
 
@@ -300,9 +305,11 @@ pub fn crate_mvps(crate_: CrateSelector, common: CrateVerifyCommon) -> Result<()
 
     mvps.sort_by(|a, b| a.1.cmp(&b.1).reverse());
 
-    for (id, count) in &mvps {
-        println!("{:>3} {} {}", count, id.id, id.url_display());
-    }
+    crate::print_mvp_ids(
+        mvps.iter().map(|(id, count)| (&id.id, *count)),
+        &trust_set,
+        &db,
+    )?;
 
     Ok(())
 }
@@ -311,7 +318,13 @@ pub fn verify_deps(crate_: CrateSelector, args: CrateVerify) -> Result<CommandEx
     let mut term = term::Term::new();
 
     let scanner = scan::Scanner::new(crate_, &args)?;
-    let events = scanner.run();
+    let trust_set = scanner.trust_set.clone();
+    let events = scanner.run(&RequiredDetails {
+        geiger: args.columns.show_geiger(),
+        owners: args.columns.show_owners(),
+        downloads: args.columns.show_downloads() || args.columns.show_leftpad_index(),
+        loc: args.columns.show_loc() || args.columns.show_leftpad_index(),
+    });
 
     // print header, only after `scanner` had a chance to download everything
     if term.stderr_is_tty && term.stdout_is_tty {
@@ -381,6 +394,8 @@ pub fn verify_deps(crate_: CrateSelector, args: CrateVerify) -> Result<CommandEx
         if crates_with_issues {
             eprintln!("Crates with issues found. Use `cargo crev repo query issue <crate> [<version>]` for details.");
         }
+
+        write_out_distrusted_ids_details(&mut std::io::stderr(), &trust_set)?;
     }
 
     Ok(if nb_unverified == 0 {
@@ -389,3 +404,19 @@ pub fn verify_deps(crate_: CrateSelector, args: CrateVerify) -> Result<CommandEx
         CommandExitStatus::VerificationFailed
     })
 }
+
+fn write_out_distrusted_ids_details(
+    stderr: &mut impl std::io::Write,
+    trust_set: &TrustSet,
+) -> Result<()> {
+    for (distrusted_id, details) in &trust_set.distrusted {
+        for reported_by in &details.reported_by {
+            write!(
+                stderr,
+                "Note: {} was ignored as distrusted by {}\n",
+                distrusted_id, reported_by
+            )?;
+        }
+    }
+    Ok(())
+}
